# Release Notes

## Latest changes

## 0.1.4 - 1st August 2022
- 🐛 Multiple notifications in the same thread gave exceptions. Now you can send as many notifications as you want.

## 0.1.3 - 31 July 2022
- 📝 Out-dated python example on main page

## 0.1.2 - 26 July 2022
- 📝 Documentation update
- 📝 Remove requirements from docs
- 📝 Update badges

## 0.1.1 - 26 July 2022
- 📝 Fix broken image in documentation

## 0.1.0 - 24 July 2022
- 🔧 Rename all references of mac-notifications to macos-notifications

## 0.0.1a1 - 24 July 2022
- 🔧 Rename project as mac-notifications was taken on pypi

## Initial release: 0.0.1a0 - 23 July 2022
- 🚀 Easy python interface. It's as simple as '`client.create_notification(title="Meeting starts now!", subtitle="Team Standup")`'
- 💥 Ability to add action buttons with callbacks!
- 📝 Ability to reply to notifications!
- ⌚ Delayed notifications.
- ⏱️ Automatically time out the notification listener.
- 📦 Just two packages (which is really just one package) as a dependency



